PCB Environment: dsn::Layer Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
dsn::Layer Struct Reference

## Public Member Functions
std::string | str () const
bool | operator< (const Layer &L) const

## Data Fields
std::string | name
std::string | type
int | copper_index {-1}
int | kicad_index {-1}
char | side {'m'}

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Loaders/DSN.hpp